local TimeToDie = TimeToDie
local L = LibStub('AceLocale-3.0'):GetLocale('TimeToDie', true)
local SML = LibStub("LibSharedMedia-3.0")

local defaultFont = GameFontNormal:GetFont()

function TimeToDie:GetValue(info)
   return self.db.profile[info.arg]
end

function TimeToDie:SetValue(info, value)
   self.db.profile[info.arg] = value
	return self:ApplySettings()
end

function TimeToDie:GetFocus()
	return self.db.profile.target == 'focus'
end

function TimeToDie:SetFocus(info, v)
   self.db.profile.target = v and 'focus' or 'target'
	return self:ApplySettings()
end

function TimeToDie:GetColor()
   local p = self.db.profile
	return p.r, p.g, p.b
end

function TimeToDie:SetColor(info, r,g,b)
   local p = self.db.profile
	p.r, p.g, p.b = r,g,b
	return self:ApplySettings()
end

TimeToDie.optionTable = {
	name = 'TimeToDie', type='group',
	desc = L["Estimated time until current target will die."],
	get = "GetValue",
	set = "SetValue",
   handler = TimeToDie,
	args = {
		[LOCKED] = {
			name = LOCKED,
         type='toggle',
			desc = LOCK_FOCUS_FRAME,
			order = 100,
         arg = 'locked',
		},
		enemy = {
			name = L["Enemy only"],
         type='toggle',
			desc = L["Only track enemy targets."],
			order = 105,
         arg = 'enemy',
		},
		[FOCUS] = {
			name = FOCUS,
         type='toggle',
			desc = L["Use focus instead of target."],
			set = "SetFocus",
			get = "GetFocus",
			order = 107,
		},
		font = {
			name = L["Font"],
         type='select',
			values  = SML and SML:List('font') or {defaultFont},
			order = 110,
         arg = 'font',
		},
		[FONT_SIZE] = {
			name = FONT_SIZE,
         type='range',
			min = 4, max = 48, step = 1,
			order = 120,
         arg = 'size',
		},
		[COLOR] = {
			name = COLOR,
         type='color',
			set = "SetColor",
			get = "GetColor",
			order = 130,
		},
		outline = {
			name = L["Outline"],
         type='select',
			desc = L["Set font outline."],
			values  = {[''] = NONE, OUTLINE = VOICE_CHAT_NORMAL, THICKOUTLINE = L["Thick"]},
			order = 140,
         arg = 'outline',
		},
		strata = {
			name = L["Strata"],
         type='select',
			desc = L["Set frame strata."],
			values  = {HIGH = HIGH, MEDIUM = AUCTION_TIME_LEFT2, LOW = LOW, BACKGROUND = BACKGROUND},
			order = 150,
         arg = 'strata',
		},
--~ 		update = {
--~ 			name = L["Update period"], type='range',
--~ 			desc = L["Set time between updates."],
--~ 			min = .1, max = 5, step = .1,
--~ 			order = 160,
--~ 		},
	},
}

--HIDE_PULLOUT_BG

function TimeToDie:RegisterOptions()
   local options = self.optionTable
   local profile = LibStub('AceDBOptions-3.0'):GetOptionsTable(self.db)

   local registry = LibStub('AceConfigRegistry-3.0')
   local dialog = LibStub('AceConfigDialog-3.0')
   LibStub('AceConfig-3.0'):RegisterOptionsTable('TimeToDie', options, {'timetodie', 'ttd'})

	registry:RegisterOptionsTable('TimeToDie Options', options)
	registry:RegisterOptionsTable('TimeToDie Profiles', profile)

   local main = dialog:AddToBlizOptions('TimeToDie Options', 'TimeToDie')
   self.optionsFrames = {
      main = main,
		profiles = dialog:AddToBlizOptions('TimeToDie Profiles', 'Profiles', 'TimeToDie'),
   }

   local function open() InterfaceOptionsFrame_OpenToCategory(main) end
   TimeToDieFrame:SetScript('OnMouseUp', open)

   if self.dataobj then
      self.dataobj.OnClick = open
      self.dataobj.OnTooltipShow = function(tooltip)
         tooltip:AddLine("TimeToDie")
         tooltip:AddLine(L["Estimated time until current target will die."])
      end
   end
end
